==> qcloudcli-1.0.zip: qcloudcli-1.0/qcloudsdkcvm/InquiryInstancePriceRequest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
from qcloudsdkcore.request import Request
class InquiryInstancePriceRequest(Request):

	def __init__(self):
		Request.__init__(self, 'cvm', 'SDK_PYTHON_1.1', 'InquiryInstancePrice', 'cvm.api.qcloud.com')

	def get_instanceType(self):
		return self.get_params().get('instanceType')

	def set_instanceType(self, instanceType):
		self.add_param('instanceType', instanceType)
		
	def get_instanceId(self):
		return self.get_params().get('instanceId')

	def set_instanceId(self, instanceId):
		self.add_param('instanceId', instanceId)
		
	def get_period(self):
		return self.get_params().get('period')

	def set_period(self, period):
		self.add_param('period', period)
	
	def get_bandwidth(self):
		return self.get_params().get('bandwidth')

	def set_bandwidth(self, bandwidth):
		self.add_param('bandwidth', bandwidth)

	def get_cpu(self):
		return self.get_params().get('cpu')

	def set_cpu(self, cpu):
		self.add_param('cpu', cpu)

	def get_mem(self):
		return self.get_params().get('mem')

	def set_mem(self, mem):
		self.add_param('mem', mem)

	def get_storageType(self):
		return self.get_params().get('storageType')

	def set_storageType(self, storageType):
		self.add_param('storageType', storageType)

	def get_storageSize(self):
		return self.get_params().get('storageSize')

	def set_storageSize(self, storageSize):
		self.add_param('storageSize', storageSize)

	def get_goodsNum(self):
		return self.get_params().get('goodsNum')

	def set_goodsNum(self, goodsNum):
		self.add_param('goodsNum', goodsNum)

	def get_bandwidthType(self):
		return self.get_params().get('bandwidthType')

	def set_bandwidthType(self, bandwidthType):
		self.add_param('bandwidthType', bandwidthType)

	def get_imageType(self):
		return self.get_params().get('imageType')

	def set_imageType(self, imageType):
		self.add_param('imageType', imageType)

	def get_imageId(self):
		return self.get_params().get('imageId')

	def set_imageId(self, imageId):
		self.add_param('imageId', imageId)

	def get_rootSize(self):
		return self.get_params().get('rootSize')

	def set_rootSize(self, rootSize):
		self.add_param('rootSize', rootSize)
		
	def get_bandwidthUpgradeStartTime(self):
		return self.get_params().get('bandwidthUpgradeStartTime')

	def set_bandwidthUpgradeStartTime(self, bandwidthUpgradeStartTime):
		self.add_param('bandwidthUpgradeStartTime', bandwidthUpgradeStartTime)
		
	def get_bandwidthUpgradeEndTime(self):
		return self.get_params().get('bandwidthUpgradeEndTime')

	def set_bandwidthUpgradeEndTime(self, bandwidthUpgradeEndTime):
		self.add_param('bandwidthUpgradeEndTime', bandwidthUpgradeEndTime)
		
	def get_startTime(self):
		return self.get_params().get('startTime')

	def set_startTime(self, startTime):
		self.add_param('startTime', startTime)

	def get_endTime(self):
		return self.get_params().get('endTime')

	def set_endTime(self, endTime):
		self.add_param('endTime', endTime)

==> qcloudcli-1.4.zip: qcloudcli-1.4/qcloudsdkcvm/InquiryInstancePriceRequest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
from qcloudsdkcore.request import Request
class InquiryInstancePriceRequest(Request):

	def __init__(self):
		Request.__init__(self, 'cvm', 'qcloudcliV1', 'InquiryInstancePrice', 'cvm.api.qcloud.com')

	def get_instanceType(self):
		return self.get_params().get('instanceType')

	def set_instanceType(self, instanceType):
		self.add_param('instanceType', instanceType)
		
	def get_instanceId(self):
		return self.get_params().get('instanceId')

	def set_instanceId(self, instanceId):
		self.add_param('instanceId', instanceId)
		
	def get_period(self):
		return self.get_params().get('period')

	def set_period(self, period):
		self.add_param('period', period)
	
	def get_bandwidth(self):
		return self.get_params().get('bandwidth')

	def set_bandwidth(self, bandwidth):
		self.add_param('bandwidth', bandwidth)

	def get_cpu(self):
		return self.get_params().get('cpu')

	def set_cpu(self, cpu):
		self.add_param('cpu', cpu)

	def get_mem(self):
		return self.get_params().get('mem')

	def set_mem(self, mem):
		self.add_param('mem', mem)

	def get_storageType(self):
		return self.get_params().get('storageType')

	def set_storageType(self, storageType):
		self.add_param('storageType', storageType)

	def get_storageSize(self):
		return self.get_params().get('storageSize')

	def set_storageSize(self, storageSize):
		self.add_param('storageSize', storageSize)

	def get_goodsNum(self):
		return self.get_params().get('goodsNum')

	def set_goodsNum(self, goodsNum):
		self.add_param('goodsNum', goodsNum)

	def get_bandwidthType(self):
		return self.get_params().get('bandwidthType')

	def set_bandwidthType(self, bandwidthType):
		self.add_param('bandwidthType', bandwidthType)

	def get_imageType(self):
		return self.get_params().get('imageType')

	def set_imageType(self, imageType):
		self.add_param('imageType', imageType)

	def get_imageId(self):
		return self.get_params().get('imageId')

	def set_imageId(self, imageId):
		self.add_param('imageId', imageId)

	def get_rootSize(self):
		return self.get_params().get('rootSize')

	def set_rootSize(self, rootSize):
		self.add_param('rootSize', rootSize)
		
	def get_bandwidthUpgradeStartTime(self):
		return self.get_params().get('bandwidthUpgradeStartTime')

	def set_bandwidthUpgradeStartTime(self, bandwidthUpgradeStartTime):
		self.add_param('bandwidthUpgradeStartTime', bandwidthUpgradeStartTime)
		
	def get_bandwidthUpgradeEndTime(self):
		return self.get_params().get('bandwidthUpgradeEndTime')

	def set_bandwidthUpgradeEndTime(self, bandwidthUpgradeEndTime):
		self.add_param('bandwidthUpgradeEndTime', bandwidthUpgradeEndTime)
		
	def get_startTime(self):
		return self.get_params().get('startTime')

	def set_startTime(self, startTime):
		self.add_param('startTime', startTime)

	def get_endTime(self):
		return self.get_params().get('endTime')

	def set_endTime(self, endTime):
		self.add_param('endTime', endTime)
